@@ -1,4 +1,3 @@
-import abc
 from typing import List, Optional, Union
 
 import attr
@@ -6,52 +5,51 @@ import attr
 from .utils import escaped_name
 
 
-class AST(abc.ABC):
-    ...
-
-
-class Definition(AST):
-    ...
-
-
-class Member(AST):
-    ...
-
-
-class Expression(AST):
+@attr.s
+class Ast:
     ...
 
 
 @attr.s
-class Definitions(AST):
+class Definition(Ast):
+    type: str = attr.ib()
 
+
+@attr.s
+class Member(Ast):
+    ...
+
+
+@attr.s
+class Expression(Ast):
+    ...
+
+
+@attr.s
+class Definitions(Ast):
     definitions: List[Definition] = attr.ib(factory=list)
 
 
 @attr.s
 class Null(Expression):
-
     type: str = attr.ib(default='null')
 
 
 @attr.s
 class NaN(Expression):
-
     type: str = attr.ib(default='NaN')
 
 
 @attr.s
 class Infinity(Expression):
-
     negative: bool = attr.ib()
     type: str = attr.ib(default='Infinity')
 
 
 @attr.s
 class Literal(Expression):
-
     type: Optional[str] = attr.ib()
-    value: Union[str, list] = attr.ib()
+    value: Union[str, list, dict] = attr.ib()
 
     def __attrs_post_init__(self):
         self.value = escaped_name(self.value)
@@ -59,7 +57,6 @@ class Literal(Expression):
 
 @attr.s
 class Value(Expression):
-
     value: str = attr.ib()
 
     def __attrs_post_init__(self):
@@ -68,14 +65,12 @@ class Value(Expression):
 
 @attr.s
 class LiteralList(Expression):
-
     type: str = attr.ib()
     value: List[Value] = attr.ib(factory=list)
 
 
 @attr.s
-class ExtendedAttribute(AST):
-
+class ExtendedAttribute(Ast):
     name: str = attr.ib()
     arguments: List[str] = attr.ib(factory=list)
     rhs: Optional[Union[Literal, LiteralList]] = attr.ib(default=None)
@@ -83,8 +78,7 @@ class ExtendedAttribute(AST):
 
 
 @attr.s
-class IdlType(AST):
-
+class IdlType(Ast):
     idl_type: Union[List['IdlType'], 'IdlType', str] = attr.ib()
     type: Optional[str] = attr.ib(default=None)
     ext_attrs: List[ExtendedAttribute] = attr.ib(factory=list)
@@ -97,8 +91,7 @@ class IdlType(AST):
 
 
 @attr.s
-class Argument(AST):
-
+class Argument(Ast):
     name: str = attr.ib()
     idl_type: IdlType = attr.ib()
     ext_attrs: List[ExtendedAttribute] = attr.ib(factory=list)
@@ -113,7 +106,6 @@ class Argument(AST):
 
 @attr.s
 class Operation(Member):
-
     name: str = attr.ib()
     idl_type: Optional[IdlType] = attr.ib()
     arguments: List[Argument] = attr.ib(factory=list)
@@ -124,7 +116,6 @@ class Operation(Member):
 
 @attr.s
 class Iterable_(Member):  # pylint: disable=invalid-name
-
     idl_type: List[IdlType] = attr.ib()
     arguments: List[Argument] = attr.ib()
     async_: bool = attr.ib()
@@ -135,7 +126,6 @@ class Iterable_(Member):  # pylint: disable=invalid-name
 
 @attr.s
 class Attribute(Member):
-
     idl_type: IdlType = attr.ib()
     name: str = attr.ib()
     ext_attrs: List[ExtendedAttribute] = attr.ib(factory=list)
@@ -149,7 +139,6 @@ class Attribute(Member):
 
 @attr.s
 class Const(Member):
-
     name: str = attr.ib()
     value: Expression = attr.ib()
     idl_type: IdlType = attr.ib()
@@ -159,7 +148,6 @@ class Const(Member):
 
 @attr.s
 class Constructor(Member):
-
     arguments: List[Argument] = attr.ib(factory=list)
     ext_attrs: List[ExtendedAttribute] = attr.ib(factory=list)
     type: str = attr.ib(default='constructor')
@@ -167,7 +155,6 @@ class Constructor(Member):
 
 @attr.s
 class MapLike(Member):
-
     readonly: bool = attr.ib()
     idl_type: List[IdlType] = attr.ib()
     arguments: List[Argument] = attr.ib(factory=list)
@@ -178,7 +165,6 @@ class MapLike(Member):
 
 @attr.s
 class SetLike(Member):
-
     readonly: bool = attr.ib()
     idl_type: List[IdlType] = attr.ib()
     arguments: List[Argument] = attr.ib(factory=list)
@@ -189,7 +175,6 @@ class SetLike(Member):
 
 @attr.s
 class Field(Member):
-
     idl_type: IdlType = attr.ib()
     name: str = attr.ib()
     default: Optional[Literal] = attr.ib()
@@ -200,7 +185,6 @@ class Field(Member):
 
 @attr.s
 class CallbackInterface(Definition):
-
     name: str = attr.ib()
     members: List[Member] = attr.ib()
     inheritance: Optional[str] = attr.ib()
@@ -211,7 +195,6 @@ class CallbackInterface(Definition):
 
 @attr.s
 class Callback(Definition):
-
     name: str = attr.ib()
     idl_type: IdlType = attr.ib()
     arguments: List[Argument] = attr.ib(factory=list)
@@ -221,7 +204,6 @@ class Callback(Definition):
 
 @attr.s
 class Interface(Definition):
-
     members: List[Member] = attr.ib()
     name: str = attr.ib()
     inheritance: Optional[str] = attr.ib(default=None)
@@ -236,7 +218,6 @@ class Interface(Definition):
 
 @attr.s
 class InterfaceMixin(Definition):
-
     members: List[Member] = attr.ib()
     name: str = attr.ib()
     inheritance: Optional[str] = attr.ib(default=None)
@@ -251,7 +232,6 @@ class InterfaceMixin(Definition):
 
 @attr.s
 class Enum(Definition):
-
     name: str = attr.ib()
     type: str = attr.ib(default='enum')
     values: List[Literal] = attr.ib(factory=list)
@@ -260,7 +240,6 @@ class Enum(Definition):
 
 @attr.s
 class Dictionary(Definition):
-
     name: str = attr.ib()
     inheritance: Optional[str] = attr.ib(default=None)
     members: List[Member] = attr.ib(factory=list)
@@ -274,7 +253,6 @@ class Dictionary(Definition):
 
 @attr.s
 class Includes(Definition):
-
     target: str = attr.ib()
     includes: str = attr.ib()
     type: str = attr.ib(default='includes')
@@ -287,7 +265,6 @@ class Includes(Definition):
 
 @attr.s
 class Typedef(Definition):
-
     idl_type: IdlType = attr.ib()
     name: str = attr.ib()
     type: str = attr.ib(default='typedef')
@@ -299,7 +276,6 @@ class Typedef(Definition):
 
 @attr.s
 class Namespace(Definition):
-
     members: List[Member] = attr.ib()
     name: str = attr.ib()
     inheritance: Optional[str] = attr.ib(default=None)
